// Copyright 2012 Google Inc. All Rights Reserved.

package com.example.android.tabcompat;

import android.os.Build;
import android.os.Bundle;
import android.support.v4.app.FragmentActivity;

/**
 * Convenience helper to build a set of tabs.
 * 
 * Once you've created an activity by extending {@link TabCompatActivity},
 * start building your tabs:
 * 
 * Call TabCompatActivity.getTabHelper(); returns TabHelper.
 * Call TabHelper.newTab(); returns CompatTab.
 * Implement an instance of CompatTabListener.
 * Call CompatTab.setText().setIcon().setTabListener() to set up each tab.
 * Call TabHelper.addTab(compatTab); you're done.
 *
 */
public abstract class TabHelper {
    protected FragmentActivity mActivity;

    protected TabHelper(FragmentActivity activity) {
        mActivity = activity;
    }
    
    /**
     * Factory method for creating TabHelper objects for a
     * given activity. Depending on which device the app is running, either a basic helper or
     * Honeycomb-specific helper will be returned.
     * Don't call this yourself; the TabCompatActivity instantiates one. Instead call
     * TabCompatActivity.getTabHelper().
     */
    public static TabHelper createInstance(FragmentActivity activity) {
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.HONEYCOMB) {
            return new TabHelperHoneycomb(activity);
        } else {
            return new TabHelperEclair(activity);
        }
    }
    
    /**
     * Create a new tab. 
     * @param tag A unique tag to associate with the tab and associated fragment
     * @return CompatTab for the appropriate android version
     */
    public CompatTab newTab(String tag) {
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.HONEYCOMB) {
            return new CompatTabHoneycomb(mActivity, tag);
        } else {
            return new CompatTabEclair(mActivity, tag);
        }
      
    }
    
    public abstract void setUp();
    
    public abstract void addTab(CompatTab tab);

    public abstract void onSaveInstanceState(Bundle outState);

    public abstract void onRestoreInstanceState(Bundle savedInstanceState);
}
